Learn R Programming

ggcyto (version 1.0.5)

+.ggcyto_GatingSet: overloaded '+' method for ggcyto.gs

Description

It takes care the speical format of some ggcyto layers. For example geom_gate or geom_stats layer with just gate(population) name specified, It only supports some special axis transformations. (See examples below)

Usage

"+"(e1, e2)
"+"(e1, e2)

Arguments

e1
An object of class ggcyto
e2
A component to add to e1

Value

ggcyto_GatingSet object

Examples

Run this code
dataDir <- system.file("extdata",package="flowWorkspaceData")
 gs <- load_gs(list.files(dataDir, pattern = "gs_manual",full = TRUE))
 p <- ggcyto(gs, aes(x = CD4, y = CD8), subset = "CD3+") + geom_hex(bins = 64)
 p <- p + geom_gate("CD4") + geom_stats() #plot CD4 gate and it is stats
 p
 p + axis_x_inverse_trans() #inverse transform the x axis into raw scale

Run the code above in your browser using DataLab