Learn R Programming

ggcyto (version 1.0.5)

compute_stats: compute the statistics of the cell population defined by gates

Description

It calls the underlining stats routine and merge it with the label position calculated by stat_position as well as the pData of flowSet.

Usage

compute_stats(fs = NULL, gates, type = "percent", value = NULL, data_range = NULL, ...)

Arguments

fs
flowSet. can be NULL when precaculated 'value' is provided
gates
a list of filters
type
can be "percent", "count" or "MFI".
value
the pre-calculated stats value. when supplied, the stats computing is skipped.
data_range
the data range for each channels
...
other arguments passed to stat_position function

Value

a data.table that contains percent and centroid locations as well as pData that used as data for geom_btext layer.

Details

This function is usually not called directly by user but used by ggcyto when geom_stat layer is added.

Examples

Run this code
data(GvHD)
fs <- GvHD[1:4]
rect.g <- rectangleGate(list("FSC-H" =  c(300,500), "SSC-H" = c(50,200)))
rect.gates <- sapply(sampleNames(fs), function(sn)rect.g)
compute_stats(fs, rect.gates)

Run the code above in your browser using DataLab