Learn R Programming

ggcyto (version 1.0.5)

ggcyto.GatingSet: Create a new ggcyto plot from a GatingSet

Description

Create a new ggcyto plot from a GatingSet

Usage

"ggcyto"(data, mapping, subset = "_parent_", ...)
"ggcyto"(data, ...)

Arguments

data
GatingSet to plot
mapping
default list of aesthetic mappings (these can be colour, size, shape, line type -- see individual geom functions for more details)
subset
character that specifies the node path or node name in the GatingSet. Default is "_parent_", which will be substitute with the actual node name based on the geom_gate layer to be added later.
...
ignored

Value

a ggcyto_GatingSet object which is a subclass of ggcyto_flowSet class.

Examples

Run this code
dataDir <- system.file("extdata",package="flowWorkspaceData")
gs <- load_gs(list.files(dataDir, pattern = "gs_manual",full = TRUE))
# 2d plot
ggcyto(gs, aes(x = CD4, y = CD8), subset = "CD3+") + geom_hex(bins = 64)

# 1d plot
ggcyto(gs, aes(x = CD4), subset = "CD3+")  + geom_density()

Run the code above in your browser using DataLab