print.ggcyto_GatingLayout: print method for ggcyto_gate_layout class
It calls arrangeGrob to arrange a list of ggplot objects stored as ggcyto_gate_layout object
Description
print method for ggcyto_gate_layout class
It calls arrangeGrob to arrange a list of ggplot objects stored as ggcyto_gate_layout object
Usage
"print"(x, ...)
"show"(object)
"show"(object)
Arguments
x
ggcyto_gate_layout, which is essentially a list of ggplot objects