Learn R Programming

ggcyto (version 1.0.5)

stat_position: compute the positions of the population statistics based on the geometic gate centroid

Description

It is usually not called directly by user but mainly used by compute_stats function (which is called by ggcyto add method when geom_states layer is added).

Usage

stat_position(gate, ...)
"stat_position"(gate, ...)
"stat_position"(gate, ...)
"stat_position"(gate, ...)

Arguments

gate
a flowCore filter
...
other arguments adjust adjust the position of the centroid

abs logical

data_range the actual data range

Value

a data.tablethe gate centroid coordinates

Examples

Run this code
data(GvHD)
fs <- GvHD[1:4]
rect.g <- rectangleGate(list("FSC-H" =  c(300,500), "SSC-H" = c(50,200)))
rect.gates <- sapply(sampleNames(fs), function(sn)rect.g)
stat_position(rect.gates)

Run the code above in your browser using DataLab