stat_position: compute the positions of the population statistics based on the geometic gate centroid
Description
It is usually not called directly by user but mainly used by compute_stats function (which is called by ggcyto add method when geom_states layer is added).
Usage
stat_position(gate, ...)
"stat_position"(gate, ...)
"stat_position"(gate, ...)
"stat_position"(gate, ...)
Arguments
gate
a flowCore filter
...
other arguments
adjust adjust the position of the centroid